;******************************************************************************
;
; THIS PROGRAM IS PROVIDED "AS IS". TI MAKES NO WARRANTIES OR
; REPRESENTATIONS, EITHER EXPRESS, IMPLIED OR STATUTORY, 
; INCLUDING ANY IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS 
; FOR A PARTICULAR PURPOSE, LACK OF VIRUSES, ACCURACY OR 
; COMPLETENESS OF RESPONSES, RESULTS AND LACK OF NEGLIGENCE. 
; TI DISCLAIMS ANY WARRANTY OF TITLE, QUIET ENJOYMENT, QUIET 
; POSSESSION, AND NON-INFRINGEMENT OF ANY THIRD PARTY 
; INTELLECTUAL PROPERTY RIGHTS WITH REGARD TO THE PROGRAM OR 
; YOUR USE OF THE PROGRAM.
;
; IN NO EVENT SHALL TI BE LIABLE FOR ANY SPECIAL, INCIDENTAL, 
; CONSEQUENTIAL OR INDIRECT DAMAGES, HOWEVER CAUSED, ON ANY 
; THEORY OF LIABILITY AND WHETHER OR NOT TI HAS BEEN ADVISED 
; OF THE POSSIBILITY OF SUCH DAMAGES, ARISING IN ANY WAY OUT 
; OF THIS AGREEMENT, THE PROGRAM, OR YOUR USE OF THE PROGRAM. 
; EXCLUDED DAMAGES INCLUDE, BUT ARE NOT LIMITED TO, COST OF 
; REMOVAL OR REINSTALLATION, COMPUTER TIME, LABOR COSTS, LOSS 
; OF GOODWILL, LOSS OF PROFITS, LOSS OF SAVINGS, OR LOSS OF 
; USE OR INTERRUPTION OF BUSINESS. IN NO EVENT WILL TI'S 
; AGGREGATE LIABILITY UNDER THIS AGREEMENT OR ARISING OUT OF 
; YOUR USE OF THE PROGRAM EXCEED FIVE HUNDRED DOLLARS 
; (U.S.$500).
;
; Unless otherwise stated, the Program written and copyrighted 
; by Texas Instruments is distributed as "freeware".  You may, 
; only under TI's copyright in the Program, use and modify the 
; Program without any charge or restriction.  You may 
; distribute to third parties, provided that you transfer a 
; copy of this license to the third party and the third party 
; agrees to these terms by its first use of the Program. You 
; must reproduce the copyright notice and any other legend of 
; ownership on each copy or partial copy, of the Program.
;
; You acknowledge and agree that the Program contains 
; copyrighted material, trade secrets and other TI proprietary 
; information and is protected by copyright laws, 
; international copyright treaties, and trade secret laws, as 
; well as other intellectual property laws.  To protect TI's 
; rights in the Program, you agree not to decompile, reverse 
; engineer, disassemble or otherwise translate any object code 
; versions of the Program to a human-readable form.  You agree 
; that in no event will you alter, remove or destroy any 
; copyright notice included in the Program.  TI reserves all 
; rights not specifically granted under this license. Except 
; as specifically provided herein, nothing in this agreement 
; shall be construed as conferring by implication, estoppel, 
; or otherwise, upon you, any license or other right under any 
; TI patents, copyrights or trade secrets.
;
; You may not use the Program in non-TI devices.

#include <signal.h>
#include <io.h>

;******************************************************************************
;    MSP430F1121 RC Timer demonstration program
;
;Description
;The CPU goes to LPM4 mode and before it goes to sleep it starts a charge cycle
;on a capacitor connected to a port input pin (here P1.2) via a resistor connected
;from another port pin (here P1.3). When the capcitor voltage reaches the schmitt
;trigger threshold (roughly 1.2V) it sets the port interrupt and wakes up the CPU.
;The ISR first discharges the capacitor and prepares it for the next cycle and then 
;performs any assigned tasks before it goes to sleep again.               
;
; MSP430F1121 RC Timer demonstration example
;            Murugavel Raju
;            Texas Instruments
;            November 2000
;            Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .section    .text
RESET:       mov.w   #__stack,R1             ; define stackpointer
StopWDT:     mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop Watchdog Timer
                                     
SetupP1:     bic.b   #0xF,&P1OUT             ; P1.0 to P1.3 cleared                   
             bis.b   #0xF,&P1DIR             ; P1.0 to P1.3 outputs
             bis.b   #BIT2,&P1IE
             
SetupP2:     bic.b   #0x1F,&P2OUT            ; P2.0 to P2.4 cleared
             bis.b   #0x1F,&P2DIR            ; P2.0 to P2.4 outputs 
                                                   
             eint                            ; Enable Interrupts
                                                   
Mainloop:    bic.b   #BIT2,&P1DIR            ; P1.2 as input to charge cap.
             bis.b   #BIT3,&P1OUT            ; P1.3 high to initiate charging
             bis.w   #LPM4,R2                ; Device in LPM4
           
             
UserServiceRoutine:
             xor.b   #BIT0,&P1OUT            ; Toggle P1.0
                        
             call    #Delay                  ; Delay to completely discharge cap.
                                             ; If service routine is long enough
                                             ; delay can be reduced or eliminated.    
             jmp     Mainloop

;****************************************************************************** 
P1_ISR:
;******************************************************************************              
             bic.b   #BIT3,&P1OUT            ; P1.3 low to stop charging
             bis.b   #BIT2,&P1DIR            ; P1.2 as output to discharge cap.                     
             clr.b   &P1IFG                  ; Clear P1 interrupt flags
             bic.w   #LPM4,0(R1)             ; Clear LPM4 from TOS
             reti        
;******************************************************************************
Delay:      ;Software delay
;******************************************************************************
             push.w  #0x100                  ; Delay to TOS
L1:          dec.w   0(R1)                   ; Decrement TOS
             jnz     L1                      ; Delay over?
             incd.w  R1                      ; Clean TOS
             ret                             ; Return from subroutine
                                                     
;****************************************************************************** 
            ; MSP430F14x Interrupt vectors             
;****************************************************************************** 
            .section    .vectors
            .org    PORT1_VECTOR,0xFF
P1_VEC:     .word   P1_ISR                  ; Port1 ISR
            .org    RESET_VECTOR,0xFF
RESET_VEC:  .word   RESET                   ; POR, ext. Reset, Watchdog
