;******************************************************************************
; File:		codec_loopback.s43
;
; Description:	This is a demo code for the low cost speech codec using internal loopback.
;
; Revisions:	1.0	13 Feb 2001
;
; Copyright:	Texas Instruments Hong Kong Ltd
;
;      Kes Tam
;      Texas Instruments Hong Kong
;
;  Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;
; Note to users:
;
; THIS PROGRAM IS PROVIDED "AS IS". TI MAKES NO WARRANTIES OR
; REPRESENTATIONS, EITHER EXPRESS, IMPLIED OR STATUTORY, 
; INCLUDING ANY IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS 
; FOR A PARTICULAR PURPOSE, LACK OF VIRUSES, ACCURACY OR 
; COMPLETENESS OF RESPONSES, RESULTS AND LACK OF NEGLIGENCE. 
; TI DISCLAIMS ANY WARRANTY OF TITLE, QUIET ENJOYMENT, QUIET 
; POSSESSION, AND NON-INFRINGEMENT OF ANY THIRD PARTY 
; INTELLECTUAL PROPERTY RIGHTS WITH REGARD TO THE PROGRAM OR 
; YOUR USE OF THE PROGRAM.
;
; IN NO EVENT SHALL TI BE LIABLE FOR ANY SPECIAL, INCIDENTAL, 
; CONSEQUENTIAL OR INDIRECT DAMAGES, HOWEVER CAUSED, ON ANY 
; THEORY OF LIABILITY AND WHETHER OR NOT TI HAS BEEN ADVISED 
; OF THE POSSIBILITY OF SUCH DAMAGES, ARISING IN ANY WAY OUT 
; OF THIS AGREEMENT, THE PROGRAM, OR YOUR USE OF THE PROGRAM. 
; EXCLUDED DAMAGES INCLUDE, BUT ARE NOT LIMITED TO, COST OF 
; REMOVAL OR REINSTALLATION, COMPUTER TIME, LABOR COSTS, LOSS 
; OF GOO.wordILL, LOSS OF PROFITS, LOSS OF SAVINGS, OR LOSS OF 
; USE OR INTERRUPTION OF BUSINESS. IN NO EVENT WILL TI'S 
; AGGREGATE LIABILITY UNDER THIS AGREEMENT OR ARISING OUT OF 
; YOUR USE OF THE PROGRAM EXCEED FIVE HUNDRED DOLLARS 
; (U.S.$500).
;
; Unless otherwise stated, the Program written and copyrighted 
; by Texas Instruments is distributed as "freeware".  You may, 
; only under TI's copyright in the Program, use and modify the 
; Program without any charge or restriction.  You may 
; distribute to third parties, provided that you transfer a 
; copy of this license to the third party and the third party 
; agrees to these terms by its first use of the Program. You 
; must reproduce the copyright notice and any other legend of 
; ownership on each copy or partial copy, of the Program.
;
; You acknowledge and agree that the Program contains 
; copyrighted material, trade secrets and other TI proprietary 
; information and is protected by copyright laws, 
; international copyright treaties, and trade secret laws, as 
; well as other intellectual property laws.  To protect TI's 
; rights in the Program, you agree not to decompile, reverse 
; engineer, disassemble or otherwise translate any object code 
; versions of the Program to a human-readable form.  You agree 
; that in no event will you alter, remove or destroy any 
; copyright notice included in the Program.  TI reserves all 
; rights not specifically granted under this license. Except 
; as specifically provided herein, nothing in this agreement 
; shall be construed as conferring by implication, estoppel, 
; or otherwise, upon you, any license or other right under any 
; TI patents, copyrights or trade secrets.
;
; You may not use the Program in non-TI devices.
;
;******************************************************************************

;-----------------------------------------------------------------------------
; Compilation control
;-----------------------------------------------------------------------------
    .equ	DIRECT_IN_OUT,0
	.equ	COMB_FILTER,1
	.equ	COMB2,0
	.equ	ADC_CUTOFF_4K,1
	.equ	DAC_CUTOFF_4K,1		;valid for COMB_FILTER = 1 and COMB2 = 0
	.equ	EIGHT_STATES,0

;-----------------------------------------------------------------------------
; include available peripheral port addresses
;-----------------------------------------------------------------------------
#include <io.h>

;-----------------------------------------------------------------------------
; Pin assignment
;-----------------------------------------------------------------------------
;
;             MSP430F13x/F14x
;     .   _________________________
;    /|\ |                         |
;     |  |                     XIN |---
;     ---| RST                     |  8MHz
;        |                    XOUT |---
;        |                         |
;        |                 P6.1/A1 |<-- Mic in
;        |                         |
;        |                P4.1/TB1 |--- 4.7K --+
;        |                         |           |
;        |                P4.2/TB2 |--- 300K --+--- Ear set out
;        |                         |
;
;
;-----------------------------------------------------------------------------


#define	P1OUT_DEFAULT	0,&P1OUT
#define	P2OUT_DEFAULT	0,&P2OUT
#define	P3OUT_DEFAULT	0,&P3OUT
#define	P4OUT_DEFAULT	0,&P4OUT
#define	P5OUT_DEFAULT	0,&P5OUT
#define	P6OUT_DEFAULT	0,&P6OUT

#define	P1DIR_DEFAULT	0,&P1DIR
#define	P2DIR_DEFAULT	0,&P2DIR
#define	P3DIR_DEFAULT	0,&P3DIR
#define	P4DIR_DEFAULT	0x06,&P4DIR
#define	P5DIR_DEFAULT	0,&P5DIR
#define	P6DIR_DEFAULT	0,&P6DIR

#define	P1SEL_DEFAULT	0,&P1SEL
#define	P2SEL_DEFAULT	0,&P2SEL
#define	P3SEL_DEFAULT	0,&P3SEL
#define	P4SEL_DEFAULT	0x06,&P4SEL
#define	P5SEL_DEFAULT	0,&P5SEL
#define	P6SEL_DEFAULT	0x03,&P6SEL

;-----------------------------------------------------------------------------
; define memory start
;-----------------------------------------------------------------------------
                .equ    RAM_orig,0x0200	        ; assume 256 bytes
                .equ	FLASH_orig,0xF000	; assume 4K size

;-----------------------------------------------------------------------------
; constants for rf speed
;-----------------------------------------------------------------------------
                .equ	CLOCK_RATE,8000			;in KHz
                .equ	SAMPLING_RATE,80			;sampling in KHz
                .equ	BIT_TIME,(CLOCK_RATE/SAMPLING_RATE)

;-----------------------------------------------------------------------------
; PWM output DC offset
;-----------------------------------------------------------------------------
        .equ	V_MID_OFFSET,(1000*BIT_TIME/917/2)	;define offset to adjust the PWM DAC dc offset to mid of Vcc
						;offset_count=0.5/(51K/(4.7K//300K+51K))*BIT_TIME

	.equ	PWM1_MAX,63			;max value of 6 bits
	.equ	PWM2_MAX,((63*5*5*3)/(4*4*4))	;max value of 6 bits plus gain
						;5=ADC input filter gain
						;5=DAC output filter gain
						;4,4,3/4 = internal multipliers

	.equ	PWM1_OFFSET,(V_MID_OFFSET-(PWM1_MAX/2))
	.equ	PWM2_OFFSET,(V_MID_OFFSET-(PWM2_MAX/2))

#if	((BIT_TIME < (V_MID_OFFSET+PWM2_MAX/2)) | (BIT_TIME < V_MID_OFFSET+PWM1_MAX/2))
PWM overflow error			;this line pretends to give compilation error
					;as PWM timer overflow
#endif

;-----------------------------------------------------------------------------
; other constants
;-----------------------------------------------------------------------------

;-----------------------------------------------------------------------------
; define register
;-----------------------------------------------------------------------------
#define	W1_reg		R15
#define	W2_reg		R14
#define	state_ctrl	R4
#if	ADC_CUTOFF_4K
#define	last_adc_sum	r6
#endif
#define	y_out		r7
#if	COMB_FILTER
#define	x_in		r9
#if	COMB2
#define	x_delta1	r10
#define	x_delta2	r11
#define	last_y		r12
#else
#if	DAC_CUTOFF_4K
#define	last_x_in	r8
#endif
#define	x_delta		r10
#endif
#else
#define	x1		r8
#define	x2		r9
#endif

;@@@
#define	in_ptr		r12
#define	out_ptr		r13

;-----------------------------------------------------------------------------
; User defined RAM location
;-----------------------------------------------------------------------------

        .section        .data
dummy:	.ds	1

	.equ	PWM_BUFFER_SIZE,8		;@@@ must be in power of 2
pwm_buffer:	.ds	PWM_BUFFER_SIZE	;@@@must be on top
drop_counter:	.ds	2		;@@@
drop_ctrl:	.ds	2		;@@@

;-----------------------------------------------------------------------------
; Program Start address
;-----------------------------------------------------------------------------

                .section        .text
main:
RESET:		mov	#__stack,R1		; Initialize stackpointer
SetupWDT:	mov	#(WDTPW+WDTHOLD),&WDTCTL	; Stop WDT

;*****************************************
; SETUP CLOCK
;*****************************************
SetupBC:
        bis.b	#XTS,&BCSCTL1		; turn on high frequency crystal
wait_HF_oscillator:			; This loop will wait till
	BIC.b	#OFIFG,&IFG1		; high frequency crystal is stable
	BIT.b	#OFIFG,&IFG1
	JnZ	wait_HF_oscillator
	call	#delay			; wait for crystal stable

	BIC.b	#OFIFG,&IFG1		; Reset osc. fault flag again

					; Then set MCLK same as LFXTCL
					; and SMCLK = LFXTCL/4
	mov.b	#(DIVS1+SELS+SELM0+SELM1),&BCSCTL2

;*****************************************
; SETUP PORT
;*****************************************
	mov.b	#P4OUT_DEFAULT
	mov.b	#P4DIR_DEFAULT
	mov.b	#P4SEL_DEFAULT

	mov.b	#P6OUT_DEFAULT
	mov.b	#P6DIR_DEFAULT
	mov.b	#P6SEL_DEFAULT

;*****************************************
; setup ADC12
;*****************************************
	and	#0xfffd,&ADC12CTL0	;selection of reference and input
	mov.b	#0x0001,&ADC12MCTL0	;multiple conversion of a single channel
	mov.b	#0x0001,&ADC12MCTL1
	mov.b	#0x0001,&ADC12MCTL2
#if EIGHT_STATES
	mov.b	#0x0081,&ADC12MCTL3
#else
	mov.b	#0x0001,&ADC12MCTL3
#endif
#if 0
	mov.b	#0x0001,&ADC12MCTL4
	mov.b	#0x0001,&ADC12MCTL5
	mov.b	#0x0001,&ADC12MCTL6
	mov.b	#0x0001,&ADC12MCTL7
	mov.b	#0x0001,&ADC12MCTL8
	mov.b	#0x0081,&ADC12MCTL9
#else
	mov.b	#0x0081,&ADC12MCTL4
#endif
#if DIRECT_IN_OUT
	mov	#0x0904,&ADC12CTL1	;repeat single channel
#else
	mov	#0x0906,&ADC12CTL1	;first conv. result is stored in ADC12MEM0
					;ADC12SC bit triggers Sample&Hold
					;ISSH trigger is inverted
					;sample pulse is generated by Sampling Timer
					;Clock Source: TIMER_B OUT 0
					;Clock divider: 1
					;repeated sequence of conversion

#endif
;	mov	#0x2210,&ADC12CTL0	;select 2*4*ADC12CLK for sampling time
	mov	#0x0010,&ADC12CTL0	;Sample&Hold Time 0
					;Sample&Hold Time 1
					;Multiple Sample&Hold OFF
					;reference voltage is off
					;ADC12 module is switched on
					;Interrupt at the end of every ADC conversion

	mov	#0x0000,&ADC12IE	;disable interrupt
					;everytime each buffer memory has ADC data
					;clear automatically
	bis	#0x0002,&ADC12CTL0	;enable conversion

;******************************************
;  set up timer_B for PWM
;******************************************
	mov	#(BIT_TIME-1),&TBCCR0
	mov	#0x0000,&TBCCR1
	mov	#(BIT_TIME/2),&TBCCR2
	mov	#0x0090,&TBCCTL0	;set outmode 4 for toggle, Interrupt enabled
;	mov	#0x0080,&TBCCTL0	;set outmode 4 for toggle
	mov	#0x02E0,&TBCCTL1	;set outmode 7 PWM reset/set
					;load new CCR1 when TBR = 0
	mov	#0x02E0,&TBCCTL2	;set outmode 7 PWM reset/set
					;load new CCR2 when TBR = 0
	mov	#0x0114,&TBCTL  	;start TIMER_B up mode, select AMCLK as input clock

;******************************************

	clr	state_ctrl

#if ADC_CUTOFF_4K
	clr	last_adc_sum
#endif
#if COMB_FILTER
	clr	x_in
	clr	y_out
#if COMB2
	clr	x_delta1
	clr	x_delta2
	clr	last_y
#else
#if DAC_CUTOFF_4K
	clr	last_x_in
#endif
	clr	x_delta
#endif
#else
	clr	y_out
#endif

	mov	#pwm_buffer,in_ptr	;@@@
	mov	#(pwm_buffer+(PWM_BUFFER_SIZE>>1)),out_ptr	;@@@
	mov	#40000,drop_counter
	clr	drop_ctrl		;@@@

	eint

main_loop:
	bis	#CPUOFF,R2
	jmp	main_loop

;*************************************************************************
; subroutine :	delay
; function : software delay
;*************************************************************************
delay:
	push	#0xFFFF	; Delay for crystal start
L1:	dec	0(R1)
	jnz	L1
	incd	R1
	ret


;************* interrupt service routines *************************************

;*************************************************************************
; subroutine :	TBCCR0_isr
; function :	Timer B CCR0 interrupt service routine
;*************************************************************************

TBCCR0_isr:
#if DIRECT_IN_OUT
	mov	&ADC12MEM0,W2_reg
	mov	W2_reg,W1_reg
	and	#03fh,W1_reg
	add	#23,W1_reg
	rla	W2_reg			;right shift 6 bits
	rla	W2_reg
	swpb	W2_reg
	and	#0ffh,W2_reg
	add	#23,W2_reg
	mov	W2_reg,&TBCCR2
	mov	W1_reg,&TBCCR1
	reti
#else

	incd	state_ctrl
	add	state_ctrl,R0
	jmp	ST0
#if !EIGHT_STATES
	jmp	ST1
	jmp	ST2
#endif
	jmp	ST3
	jmp	ST4
	jmp	ST5
	jmp	ST6
	jmp	ST7
	jmp	ST8
	jmp	ST9

ST0:
	mov	W2_reg,&TBCCR2
	mov	W1_reg,&TBCCR1

#if 1
	mov	#ADC12MEM0,W1_reg
	mov	@W1_reg+,W2_reg  
	add	@W1_reg+,W2_reg  
	add	@W1_reg+,W2_reg  
	add	@W1_reg+,W2_reg  

#if EIGHT_STATES
	mov	W2_reg,W1_reg			;mul 5/4
	rra	W1_reg
	rra	W1_reg
	add	W1_reg,W2_reg
#else
	add	@W1_reg+,W2_reg  
#endif
#else
	inc	r5
	inc	r5
	bic	#0xFFF1,r5
	mov	SIN_TABLE(r5),W2_reg
#endif

#if ADC_CUTOFF_4K
	mov	W2_reg,W1_reg
	add	last_adc_sum,W2_reg
	rrc	W2_reg				;unsigned shift
	mov	W1_reg,last_adc_sum
#endif

	rra	W2_reg
	rra	W2_reg

#if COMB_FILTER

#if COMB2
	rra	W2_reg				;avoid overflow as gain=25 for 2nd order comb filter
						;however, this reduce the resolution to 11 bits

	mov	y_out,W1_reg			;this will be last_y

	rla	y_out				;calculate current y
	sub	last_y,y_out
	add	x_delta2,y_out
	sub	x_delta1,y_out

	mov	W1_reg,last_y			;update last_y

	mov	x_delta2,x_delta1		;get new x_delta1
	mov	W2_reg,x_delta2
	sub	x_in,x_delta2			;get new x_delta2
	mov	W2_reg,x_in			;get current x

#else

	add	x_delta,y_out			;get current y

#if DAC_CUTOFF_4K
;	rra	W2_reg				;avoid overflow and compensate extra gain of 2
	mov	W2_reg,x_delta
	sub	last_x_in,x_delta		;get current x_delta
	mov	x_in,last_x_in
#else
	mov	W2_reg,x_delta
	sub	x_in,x_delta			;get current x_delta
#endif
	mov	W2_reg,x_in			;get current x
#endif

	mov	y_out,W2_reg

#else					        /* moving avg */
	mov	x2,x1
	mov	W2_reg,x2
	mov	x1,W2_reg
	rla	W2_reg				;mul 5
	rla	W2_reg
#if !EIGHT_STATES
	add	x1,W2_reg
#endif
	mov	W2_reg,y_out
#endif
	jmp	TBCCR0_isr_exit
ST2:
ST4:
ST6:
ST8:
	mov	W2_reg,&TBCCR2
	mov	W1_reg,&TBCCR1

#if COMB_FILTER

#if COMB2
	mov	y_out,W1_reg			;this will be last_y

	rla	y_out				;calculate current y
	sub	last_y,y_out
	add	x_delta2,y_out
	sub	x_delta1,y_out

	mov	W1_reg,last_y			;update last_y
		
#else

	add	x_delta,y_out		;update current y

#endif

	mov	y_out,W2_reg

#else
	sub	x1,y_out
	add	x2,y_out
	mov	y_out,W2_reg
#endif
	jmp	TBCCR0_isr_exit

ST9:	mov	#-2,state_ctrl
ST1:
ST3:
ST5:
ST7:
	mov	    W2_reg,0(in_ptr)		;@@@
	incd	in_ptr				;@@@

	mov	    @out_ptr+,W2_reg
	dec	    drop_counter
	jnz	    no_drop
	mov	    #100,drop_counter
	decd	in_ptr
	decd	out_ptr
no_drop:
	bic	#PWM_BUFFER_SIZE,in_ptr		;@@@
	bic	#PWM_BUFFER_SIZE,out_ptr	;@@@

#if (COMB_FILTER & (COMB2 | DAC_CUTOFF_4K))
	clrc
	rrc	W2_reg			;unsigned shift
#endif

	rra	W2_reg
	rra	W2_reg
#if EIGHT_STATES
	mov	W2_reg,W1_reg
	rra	W1_reg
	rra	W1_reg
	add	W1_reg,W2_reg
#endif

#if (COMB_FILTER & COMB2)
	rra	W2_reg
#if 1	/* mul 5/4 */
	mov	W2_reg,W1_reg
	rra	W1_reg
	rra	W1_reg
	add	W1_reg,W2_reg
#endif
#else
	mov	W2_reg,W1_reg		;mul 3/4
	rra	W1_reg
	rra	W1_reg
	sub	W1_reg,W2_reg
#endif

	mov	W2_reg,W1_reg
	and	#0x3F,W1_reg
	rla	W2_reg			;right shift 6 bits
	rla	W2_reg

	swpb	W2_reg
	and	#0xFF,W2_reg		;more than 6 bits required
	add	#PWM2_OFFSET,W2_reg
	add	#PWM1_OFFSET,W1_reg

TBCCR0_isr_exit:
	reti

#endif

;---------------------------------------------------------------------------
SIN_TABLE:
	.word	(2048+355)*5
	.word	(2048+1674)*5
	.word	(2048+2012)*5
	.word	(2048+1172)*5
	.word	(2048-355)*5
	.word	(2048-1674)*5
	.word	(2048-2012)*5
	.word	(2048-1172)*5

;---------------------------------------------------------------------------
        .section    .vectors
	.word	RESET		; no source
	.word	RESET		; P2.x
	.word	RESET		; USART1 TX
	.word	RESET		; USART1 RX
	.word	RESET		; P1.x
	.word	RESET		; Timer_A1, Timer_A2, TAR overflow
	.word	RESET		; Timer_A0
	.word	RESET		; ADC12
	.word	RESET		; USART0 TX
	.word	RESET		; USART0 RX
	.word	RESET		; Watchdog/Timer, Timer mode
	.word	RESET		; Comparator_A
	.word	RESET		; Timer_B1 to Timer_B6, TBR overflow
	.word	TBCCR0_isr	; Timer_B0
	.word	RESET		; NMI, Osc. fault, Flash access violation
	.word	RESET		; POR, ext. Reset, Watchdog
