#include <io.h>
;******************************************************************************
;   MSP-FET430x110 Demo - Comp_A Detect Theashold, Set P1.0 if P2.3 > 0.25*Vcc  
;
;   Description; Use comparator_A to detect a voltage threashold. Using an
;   external potentiometer, an interesting analog voltage is applied to P2.3. 
;   Comparator_A compares the interesting voltage to an internal reference 
;   voltage, in this example 0.25*VCC.  If the interesting voltage is higher 
;   than 0.25*Vcc, P1.0 is set, if not, P1.0 is reset.
;   ACLK = n/a, MCLK = SMCLK = default DCO ~ 800k 
;
;                 MSP430F1121
;             -----------------
;        /|\ |              XIN|-  
;         |  |                 |
;         ---|RST          XOUT|-
;         |  |                 |
;         R<-|P2.3         P1.0|--> LED
;         |  |                 |			 
;         ---|VSS
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .section    .text
RESET:      mov.w   #0x300,R1               ; Initialize stackpointer
StopWDT:    mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop WDT
SetupP1:    bis.b   #0x01,&P1DIR            ; P1.0 = output
SetupCA:    mov.b   #CARSEL+CAREF0+CAON,&CACTL1   ; 0.25Vcc = -comp, on
            mov.b   #P2CA0,&CACTL2          ; P2.3 = +comp 
                                            ;													  
Mainloop:   bit.b   #CAOUT,&CACTL2          ; Test comparator_A output
            jz      OFF                     ; jmp--> if CAOUT reset
                                            ;
ON:         bis.b   #0x01,&P1OUT            ; P1.0 = 1 
            jmp     Mainloop                ;  
OFF:        bic.b   #0x01,&P1OUT            ; P1.0 = 0 
            jmp     Mainloop                ;  
                                            ;
;------------------------------------------------------------------------------ 
;           Interrupt Vectors Used MSP430x11x1         
;------------------------------------------------------------------------------ 
            .section    .vectors
            .org    0x1E,0xFF               ; MSP430 RESET Vector
            .word   RESET                   ; 
