#include <io.h>
;******************************************************************************
;   MSP-FET430x110 Demo - LPM4, Pulse P.0 on P2.0_ISR  
;
;   Description; This program operates normally in LPM4. A hi/low transition
;   on P2.0 will trigger P2_ISR, which will exit force an exit from LPM4 and 
;   pulse P1.0.  JTAG must be released twice if using the FET, to release 
;   breakpoint control.  This can be used to demonstrated LPM4.  
;   ACLK = n/a, MCLK = SMCLK = default DCO ~ 800k 
;
;                MSP430F1121
;             -----------------
;         /|\|              XIN|-  
;          | |                 |
;          --|RST          XOUT|-
;      /|\   |                 |
;       --o--| P2.0        P1.0|-->LED
;      \|/
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .section    .text
RESET:      mov.w   #0x300,R1               ; Initialize stackpointer
StopWDT:    mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop WDT
SetupP1:    mov.b   #0xFF,&P1DIR            ; All P1.x outputs
SetupP2:    mov.b   #0xFE,&P2DIR            ; P2.0 input, P2.x output
            bis.b   #0x01,&P2IES            ; P2.0 interrupt hi/low edge 
            eint                            ; General enable interrupts
                                            ;				  
;------------------------------------------------------------------------------ 
Mainloop:   ;Pulse P1.0, enable P2.0 ISR, enter LPM4
;------------------------------------------------------------------------------ 
            bis.b   #0x01,&P1OUT            ; P1.0 = set
Debounce:   push.w  #0xFFFF                 ; Delay TOS 
D1:         dec.w   0(R1)                   ; 
            jnz     D1                      ;
            incd.w  R1                      ; Clean up stack
            bic.b   #0x01,&P1OUT            ; P1.0 = reset
            bit.b   #0x01,&P2IN             ; P2.0 = 0 ?
            jnc     Debounce                ; P2.0 = 0, then jump 
            bic.b   #0x01,&P2IFG            ; P2.0 IFG cleared 
            bis.b   #0x01,&P2IE             ; P2.0 interrupt enabled
            bis.w   #LPM4,R2                ; Enter LPM4
            jmp     Mainloop                ; Again
                                            ;
;------------------------------------------------------------------------------ 
P2_ISR:     ;Exit LPM4, disable P2.0 interrupt      
;------------------------------------------------------------------------------ 
            bic.w   #LPM4,0(R1)             ; Exit LPM4 on reti
            bic.b   #0x01,&P2IE             ; P2.0 interrupt disabled
            reti                            ; Return from ISR
                                            ;
;------------------------------------------------------------------------------ 
;           Interrupt Vectors Used MSP430x11x1         
;------------------------------------------------------------------------------ 
            .section    .vectors
            .org    0x06,0xFF               ; P2.x Vector
            .word   P2_ISR                  ; 
            .org    0x1E,0xFF               ; MSP430 RESET Vector
            .word   RESET                   ; 
