#include <io.h>
;******************************************************************************
;   MSP-FET430P120 Demo - USART0  UART 9600 Echo ISR, HF XTAL ACLK
;
;   Description; Echo a received character, RX ISR used. Normal mode is LPM0, 
;   USART0 RX interrupt triggers TX Echo. Though not required, MCLK = LFXT1  
;   ACLK = MCLK = UCLK0 = LFXT1 = 3.58MHz, SMCLK = DCOCLK
;   Baud rate divider with 3.58Mhz XTAL @9600 = 3.58MHz/9600 = 372 (0x174)
;   //*USART0 interrupt flags are in different SFR's from MSP430F14x/13x*// 
;   //*An external 8MHz XTAL on XIN XOUT is required for ACLK*//	  
;
;              
;               MSP430F123(2)   
;             -----------------
;         /|\|              XIN|-  
;          | |                 | 3.58MHz  
;          --|RST          XOUT|-
;            |                 |
;            |             P3.4|------------> 
;            |                 | 9600 - 8N1
;            |             P3.5|<------------
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .section    .text
RESET:      mov.w   #0x300,R1               ; Initialize stackpointer
            call    #Init_Sys               ;
                                            ;   
Mainloop:   bis.b   #CPUOFF,R2              ; Enter LPM0
            nop                             ; Needed only for C-spy
                                            ;
;------------------------------------------------------------------------------ 
Init_Sys:   ;Initalize MSP430 system
;------------------------------------------------------------------------------ 
StopWDT:    mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop WDT
SetupBC:    bis.b   #XTS,&BCSCTL1           ; LFXT1 = HF XTAL
SetupOsc:   bic.b   #OFIFG,&IFG1            ; Clear OSC fault flag 
            mov.w   #0xFF,R15               ; R15 = Delay 
SetupOsc1:  dec.w   R15                     ; Additional delay to ensure start 
            jnz     SetupOsc1               ;
            bit.b   #OFIFG,&IFG1            ; OSC fault flag set? 
            jnz     SetupOsc                ; OSC Fault, clear flag again 
            bis.b   #SELM1+SELM0,&BCSCTL2   ; MCLK = LFXT1
SetupUART0: mov.b   #CHAR,&UCTL0            ; 8-bit characters
            mov.b   #SSEL0,&UTCTL0          ; UCLK = ACLK
            mov.b   #0x74,&UBR00            ; 3.58Mhz 9600 - 372
            mov.b   #0x01,&UBR10            ; 3.58Mhz 9600
            mov.b   #0x00,&UMCTL0           ; 3.58MHz no modulation 19200
            bis.b   #UTXE0+URXE0,&ME2       ; Enable USART0 TXD/RXD
            bis.b   #URXIE0,&IE2            ; Enable USART0 RX interrupt
SetupP3:    bis.b   #0x30,&P3SEL            ; P3.4,5 = USART0 TXD/RXD
            bis.b   #0x10,&P3DIR            ; P3.4 = output direction 
            eint                            ; General enable interrupts
            ret                             ; Return from subroutine
                                            ;             
;------------------------------------------------------------------------------ 
USART0RX_ISR:   ;Confirm TX buffer is ready, then Echo back RXed character
;------------------------------------------------------------------------------ 
TX1:        bit.b   #UTXIFG0,&IFG2          ; USART0 TX buffer ready?
            jz      TX1                     ; Jump is TX buffer not ready
            mov.b   &RXBUF0,&TXBUF0         ; TX -> RXed character
            reti                            ; 
                                            ;
;------------------------------------------------------------------------------ 
;           Interrupt Vectors Used MSP430x12x(2)        
;------------------------------------------------------------------------------ 
            .section    .vectors
            .org    0x0E,0xFF               ; 
            .word   USART0RX_ISR            ; USART0 receive
            .org    0x1E,0xFF               ; 
            .word   RESET                   ; POR, ext. Reset, Watchdog
