#include <io.h>
;******************************************************************************
;   MSP-FET430P140 Demo - LFXT1/MCLK configured to operate with HF XTAL
;
;   Description; Proper selection of an external HF XTAL for MCLK is shown by
;   first polling the OSC fault until XTAL is stable - only then is MCLK
;   sourced by LFXT1.  MCLK is on P5.4
;   ACLK = MCLK = LFXT1 = HFXTAL, SMCLK = DCO  
;   //** HF XTAL NOT INSTALLED ON FET **//
;
;                MSP430F149
;             -----------------
;         /|\|              XIN|-  
;          | |                 | HF XTAL (455k - 8Mhz)
;          --|RST          XOUT|-
;            |                 |
;            |             P5.4|-->MCLK = XTAL
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .section    .text
RESET:      mov.w   #0xA00,R1               ; Initialize 'F149 stackpointer
SetupWDT:   mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop WDT
                                            ;           
SetupBC:    bis.b   #XTS,&BCSCTL1           ; LFXT1 = HF XTAL
SetupOsc:   bic.b   #OFIFG,&IFG1            ; Clear OSC fault flag 
            mov.w   #0xFF,R15               ; R15 = Delay 
SetupOsc1:  dec.w   R15                     ; Additional delay to ensure start 
            jnz     SetupOsc1               ;
            bit.b   #OFIFG,&IFG1            ; OSC fault flag set? 
            jnz     SetupOsc                ; OSC Fault, clear flag again 
            bis.b   #SELM1+SELM0,&BCSCTL2   ; MCLK = LFXT1
SetupP5:    bis.b   #0x10,&P5DIR            ; P5.4 output
            bis.b   #0x10,&P5SEL            ; P5.4 option
                                            ;           
Mainloop:   jmp     Mainloop                ; Repeat
                                            ;           
;------------------------------------------------------------------------------ 
;           Interrupt Vectors Used MSP430x13x/14x         
;------------------------------------------------------------------------------ 
            .section    .vectors
            .org    0x1E,0xFF               ; MSP430 RESET Vector
            .word   RESET                   ; 
