#include <io.h>
;******************************************************************************
;   MSP-FET430P140 Demo - LPM3 Using WDT ISR, 32kHz ACLK
;
;   Description; This program operates MSP430 normally in LPM3, pulsing P1.0 
;   at 4 second intervals. WDT ISR used to wake-up system. All I/O configured 
;   as low outputs to eliminate floating inputs. Current consumption does 
;   increase when LED is powered on P1.0. Demo for measuring LPM3 current. 
;   ACLK = LFXT1/4 = 32768/4, MCLK = SMCLK = default DCO
;   //*External watch crystal on XIN XOUT is required for ACLK*//	  
;
;                 MSP430F149
;             -----------------
;         /|\|              XIN|-  
;          | |                 | 32kHz  
;          --|RST          XOUT|-
;            |                 |
;            |             P1.0|-->LED
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .section    .text
RESET:      mov.w   #0xA00,R1               ; Initialize 'F149 stackpointer
SetupBC:    bis.b   #DIVA1,&BCSCTL1         ; ACLK/4 
SetupWDT:   mov.w   #WDT_ADLY_1000,&WDTCTL  ; WDT 1s*4 Interval Timer 
            bis.b   #WDTIE,&IE1             ; Enable WDT Interrupt 
SetupP1:    mov.b   #0xFF,&P1DIR            ; All P1.x Outputs
            clr.b   &P1OUT                  ; All P1.x Reset
SetupP2:    mov.b   #0xFF,&P2DIR            ; All P2.x Outputs
            clr.b   &P2OUT                  ; All P2.x Reset
SetupP3:    mov.b   #0xFF,&P3DIR            ; All P3.x Outputs
            clr.b   &P3OUT                  ; All P3.x Reset
SetupP4:    mov.b   #0xFF,&P4DIR            ; All P4.x Outputs
            clr.b   &P4OUT                  ; All P4.x Reset
SetupP5:    mov.b   #0xFF,&P5DIR            ; All P5.x Outputs
            clr.b   &P5OUT                  ; All P5.x Reset
SetupP6:    mov.b   #0xFF,&P6DIR            ; All P6.x Outputs
            clr.b   &P6OUT                  ; All P6.x Reset
            eint                            ; Enable Interrupts
                                            ;                                                     
Mainloop:   bis.w   #LPM3,R2                ; Enter LPM3
            bis.b   #0x01,&P1OUT            ; Set P1.0
            push.w  #5000                   ; Delay to TOS
Pulse:      dec.w   0(R1)                   ; Decrement TOS
            jnz     Pulse                   ; Delay done?
            bic.b   #0x01,&P1OUT            ; Reset P1.0
            jmp     Mainloop                ; Again
                                            ;
;------------------------------------------------------------------------------
WDT_ISR:    ;Exit LPM3 on reti
;------------------------------------------------------------------------------
            bic.w   #LPM3,0(R1)             ; Clear LPM3 from TOS
            reti                            ;        
                                            ;
;----------------------------------------------------------------------------- 
;           Interrupt Vectors Used MSP430x13x/14x        
;----------------------------------------------------------------------------- 
            .section    .vectors
            .org    0x14,0xFF               ; WDT Vector
            .word   WDT_ISR                 ; 
            .org    0x1E,0xFF               ; MSP430 RESET Vector
            .word   RESET                   ; 
