#include <io.h>
;******************************************************************************
;   MSP-FET430P140 Demo - USART0 SPI Interface to HC165 Shift Register 
;
;   Description: This program demonstrate a USART0 in SPI mode interface to a 
;   an 'HC165 shift register.  Read 8-bit Data from A-H are stored at a RAM
;   byte 0x200 defined as Data.  
;   //**SWRST** please see MSP430x1xx Users Guide for description //
;
;                          MSP430F149
;                       -----------------
;                   /|\|              XIN|-  
;                    | |                 | 
;          HC165     --|RST          XOUT|-
;        ----------    |                 |
;    8  |      /LD|<---|P3.0             |    
;   -\->|A-H   CLK|<---|P3.3/UCLK0       |
;     |-|INH    QH|--->|P3.2/SOMI        |    
;     |-|SER      |    |                 | 
;     v
;
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .equ    Data,0x200                  

            .section    .text
RESET:      mov.w   #0xA00,R1               ; Initialize 'F149 stackpointer
            call    #Init_Sys               ; Initialize system
                                            ;
Mainloop:   call    #RX_HC165               ; Read HC165
            mov.b   &RXBUF0,&Data           ; Data = HC165
            jmp     Mainloop                ; Repeat
                                            ;
;----------------------------------------------------------------------------- 
RX_HC165:
;----------------------------------------------------------------------------- 
            bic.b   #0x01,&P3OUT            ; Latch data into 'HC165
            bis.b   #0x01,&P3OUT            ; 
            bic.b   #URXIFG0,&IFG1          ; Clear RXBUF flag
            mov.b   #0x00,&TXBUF0           ; Dummy write to start SPI
L1:         bit.b   #URXIFG0,&IFG1          ; RXBUF ready?
            jnc     L1                      ; 1 = ready
            ret                             ;
                                            ;
;----------------------------------------------------------------------------- 
Init_Sys:   ;Subroutine to Initialize MSP430F149 Peripherials
;----------------------------------------------------------------------------- 
StopWDT:    mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop watchdog timer
SetupP3:    bis.b   #0x0C,&P3SEL            ; P3.2,3 SPI option select
            bis.b   #0x09,&P3DIR            ; P3.3,0 output direction
SetupSPI:   bis.b   #0x40,&ME1              ; Enable USART0 SPI
            bis.b   #CKPH+SSEL1+SSEL0+STC,&UTCTL0 ;* SMCLK, 3-pin mode
            mov.b   #CHAR+SYNC+MM,&UCTL0    ; 8-bit SPI Master **SWRST**
            mov.b   #0x02,&UBR00            ; SMCLK/2 for baud rate
            clr.b   &UBR10                  ; SMCLK/2 for baud rate
            clr.b   &UMCTL0                 ; Clear modulation
            ret                             ; Return from subroutine
;
;-----------------------------------------------------------------------------
;           Interrupt Vectors Used MSP430x13x/14x         
;-----------------------------------------------------------------------------
            .section    .vectors
            .org    0x1E,0xFF               ; POR, ext. Reset, Watchdog, Flash
            .word   RESET                   ; 
