#include <io.h>
;******************************************************************************
;   MSP-FET430P410 Demo - Timer_A Toggle P5.1, CCR0 upmode ISR, DCO SMCLK 
;
;   Description; Toggle P5.1 using using software and TA_0 ISR. Timer_A is 
;   configured in upmode, thus the timer will overflow when TAR counts to CCR0.  
;   In this example, CCR0 is loaded with 20000. 
;   ACLK = n/a, MCLK = SMCLK = TACLK = default DCO
;
;                MSP430F413
;             -----------------
;         /|\|              XIN|-  
;          | |                 |
;          --|RST          XOUT|-
;            |                 |
;            |             P5.1|-->LED
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .section    .text
RESET:      mov.w   #0x300,R1               ; Initialize stackpointer
StopWDT:    mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop WDT
SetupTA:    mov.w   #TASSEL1+TACLR,&TACTL   ; SMCLK, clear TAR
SetupC0:    mov.w   #CCIE,&CCTL0            ; CCR0 interrupt enabled
            mov.w   #20000,&CCR0            ; 
SetupP5:    bis.b   #0x02,&P5DIR            ; P5.1 output
            bis.w   #MC0,&TACTL             ; Start Timer_a in upmode
            eint                            ; Enable interrupts
                                            ;						  
Mainloop:   bis.w   #CPUOFF,R2              ; CPU off
            nop                             ; Required for C-spy
                                            ;
;------------------------------------------------------------------------------ 
TA0_ISR:    ;Toggle P5.1
;------------------------------------------------------------------------------ 
            xor.b   #0x02,&P5OUT            ; Toggle P5.1
            reti                            ;		 
                                            ;
;----------------------------------------------------------------------------- 
;           Interrupt Vectors Used MSP430x13x/14x         
;----------------------------------------------------------------------------- 
            .section    .vectors
            .org    0x0C,0xFF               ; Timer_A0 Vector
            .word   TA0_ISR                 ; 
            .org    0x1E,0xFF               ; MSP430 RESET Vector
            .word   RESET                   ; 
