#include <io.h>
;*******************************************************************************
;   MSP-FET430P440 Demo - FLL+ clock, runs internal DCO at8 Mhz
;
;   Description "FET440_8MhzDCO": This program demostrates setting the internal
;   DCO to run at 8Mhz with auto-calibration by the FLL+.
;   ACLK = LFXT1 = 32768, MCLK = SMCLK = DCOCLK = (n+1) x 2 x ACLK 
;   //*An external watch crystal is required on XIN/XOUT for ACLK*//	  
;
;                MSP430F449
;             -----------------
;         /|\|              XIN|-  
;          | |                 | 32khz xtal
;          --|RST          XOUT|-                                       
;            |                 |
;            |             P1.1|--> MCLK = 8Mhz
;            |                 |
;            |             P1.5|--> ACLK = 32khz
;            |                 |
;
;   B. Merritt - meb
;   Texas Instruments Inc.
;   February 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;*******************************************************************************
            .section    .text
RESET:      mov.w   #0xA00,R1               ;Initialize '449 stackpointer
SetupWDT:   mov.w   #WDTPW+WDTHOLD,&WDTCTL  ;stop WDT
SetupFLL2:  bis.b   #FN_4,&SCFI0            ;x2 DCO, 8MHz nominal DCO  
            bis.b   #DCOPLUS+XCAP14PF,&FLL_CTL0 ; DCO+, configure load caps
            mov.b   #121,&SCFQCTL           ;(121+1) x 2 x 32768 = 7.99 Mhz
SetupPorts: bis.b   #0x22,&P1DIR            ;P1.1 & P1.5 to output direction
            bis.b   #0x22,&P1SEL            ;P1.1 & P1.5 to output MCLK & ACLK
                                            ;
Mainloop:   jmp     Mainloop                ;loop with CPU running
                                            ;
;----------------------------------------------------------------------------- 
;           MSP430F43x/44x interrupt vectors used         
;----------------------------------------------------------------------------- 
            .section    .vectors
            .org    0x1E,0xFF               ; MSP430 RESET Vector
            .word   RESET                   ; 
