#include <io.h>
;*****************************************************************************
;   MSP-FET430P440 Demo - Flash In-System Program memory 
;
;   Description; This program demonstrates in-system programming of FLASH
;   memory.  Two variable bytes @ 0x1080/0x1081 in SegmentA are modified.
;   The subroutine Update_SegA will save the variables on the stack, 
;   incrementing 0x1080 and decrementing 0x1081. SegmentA is first erased and
;   then re-Flashed with the modified variables on the TOS. Flash timing 
;   generator must meet datasheet specifications, this program assumes a 
;   watch crystal is used,the FLL is active and MCLK = 1048576. A breakpoint
;   can be set on "jmp Mainloop", observing flash memory locations 
;   0x1080/0x1081 in a memory window.
;   //*An external watch crystal is required on XIN/XOUT for ACLK*//	  
;
;                 MSP430F449
;             -----------------
;         /|\|              XIN|-  
;          | |                 | 32kHz
;          --|RST          XOUT|-
;            |                 |
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .section    .text
RESET:      mov.w   #0xA00,R1               ; Initialize '449 stackpointer
StopWDT:    mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop WDT
SetupFLL:   bis.b   #XCAP14PF,&FLL_CTL0     ; Configure load caps
                                            ;				          							  
Mainloop:   call    #Update_SegA            ;
Delay:      push.w  #0xFFFF                 ; Delay TOS
D1:         dec.w   0(R1)                   ; Decrement delay TOS
            jnz     D1                      ;
            incd.w  R1                      ; Clean up stack
            jmp     Mainloop                ; Repeat
                                            ;
;------------------------------------------------------------------------------
Update_SegA:    ;Increment byte 0x1080, decrement byte 0x1081 in Flash SegA
;------------------------------------------------------------------------------
Timing:     mov.w   #FWKEY+FSSEL0+FN1,&FCTL2  ; *Timing generator = MCLK/3
            push.b  &0x1081                 ; Save contents of 0x1081 on TOS 
            push.b  &0x1080                 ; Save contents of 0x1080 on TOS 
            inc.b   0(R1)                   ; Increment TOS
            dec.b   2(R1)                   ; Decrement TOS
                                            ;
Erase_SegA: mov.w   #FWKEY,&FCTL3           ; Lock = 0
            mov.w   #FWKEY+ERASE,&FCTL1     ; Erase bit = 1
            mov.w   #0,&0x1080              ; Dummy write to SegA to erase
                                            ;
Write_SegA: mov.w   #FWKEY+WRT,&FCTL1       ; Write bit = 1
            pop.b   &0x1080                 ; Write to Flash 0x1080
            pop.b   &0x1081                 ; Write to Flash 0x1081
            mov.w   #FWKEY+LOCK,&FCTL3      ; Lock = 1
            ret                             ;
                                            ;
;----------------------------------------------------------------------------- 
;           Interrupt Vectors Used MSP430x44x         
;----------------------------------------------------------------------------- 
            .section    .vectors
            .org    0x1E,0xFF               ; MSP430 RESET Vector
            .word   RESET                   ; 
